ged4py\.detail package
======================

Submodules
----------

ged4py\.detail\.date module
---------------------------

.. automodule:: ged4py.detail.date
    :members:
    :undoc-members:
    :show-inheritance:

ged4py\.detail\.io module
-------------------------

.. automodule:: ged4py.detail.io
    :members:
    :undoc-members:
    :show-inheritance:

ged4py\.detail\.name module
---------------------------

.. automodule:: ged4py.detail.name
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ged4py.detail
    :members:
    :undoc-members:
    :show-inheritance:
